(this.webpackJsonpst_blogpost_component=this.webpackJsonpst_blogpost_component||[]).push([[0],{67:function(t,e,n){"use strict";n.r(e);var r=n(4),s=n.n(r),a=n(53),c=n.n(a),i=n(0),o=n(1),l=n(2),b=n(3),j=n(47),p=n(92),u=n(95),d=n(96),h=n(97),O=n(94),g=n(98),x=n(91),m=n(9),f=function(t){Object(l.a)(n,t);var e=Object(b.a)(n);function n(){var t;Object(o.a)(this,n);for(var r=arguments.length,s=new Array(r),a=0;a<r;a++)s[a]=arguments[a];return(t=e.call.apply(e,[this].concat(s))).state={url:null},t.render=function(){var e=t.props.args.title,n=t.props.args.subtitle,r=t.props.args.body,s=t.props.args.link,a=t.props.args.img_link;return Object(m.jsx)("div",{style:{padding:"0.5rem"},children:Object(m.jsxs)(p.a,{variant:"outlined",children:[Object(m.jsx)(u.a,{title:e,subheader:n}),Object(m.jsx)(d.a,{sx:{height:100},image:a}),Object(m.jsx)(h.a,{children:Object(m.jsx)(O.a,{variant:"body2",children:r})}),Object(m.jsx)(g.a,{disableSpacing:!0,children:Object(m.jsx)(x.a,{size:"small",onClick:function(){return t.setState((function(){return{url:s}}),(function(){return j.a.setComponentValue(t.state.url)}))},children:"Open Article"})})]})})},t}return Object(i.a)(n)}(j.b),v=Object(j.c)(f);c.a.render(Object(m.jsx)(s.a.StrictMode,{children:Object(m.jsx)(v,{})}),document.getElementById("root"))}},[[67,1,2]]]);
//# sourceMappingURL=main.a8adb8b7.chunk.js.map